@@ -7,6 +7,9 @@ t_asset = "asset"
 t_downloader = "downloader"
 t_dependency = "dependency"
 t_scheduler = "scheduler"
+t_credits = "credits"
+t_auth = "auth"
+t_version = "version"
 
 t_secret = "secret"
 
